==> MesaLib-7.9.2.tar.bz2: Mesa-7.9.2/src/mesa/main/enable.h <==
/**
 * \file enable.h
 * Enable/disable/query GL capabilities.
 */

/*
 * Mesa 3-D graphics library
 * Version:  3.5
 *
 * Copyright (C) 1999-2001  Brian Paul   All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * BRIAN PAUL BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */


#ifndef ENABLE_H
#define ENABLE_H


#include "mtypes.h"


extern void
_mesa_set_enable( GLcontext* ctx, GLenum cap, GLboolean state );

extern void GLAPIENTRY
_mesa_Disable( GLenum cap );

extern void GLAPIENTRY
_mesa_Enable( GLenum cap );

extern GLboolean GLAPIENTRY
_mesa_IsEnabled( GLenum cap );

extern void
_mesa_set_enablei(GLcontext *ctx, GLenum cap, GLuint index, GLboolean state);

extern void GLAPIENTRY
_mesa_DisableIndexed( GLenum cap, GLuint index );

extern void GLAPIENTRY
_mesa_EnableIndexed( GLenum cap, GLuint index );

extern GLboolean GLAPIENTRY
_mesa_IsEnabledIndexed( GLenum cap, GLuint index );

extern void GLAPIENTRY
_mesa_EnableClientState( GLenum cap );

extern void GLAPIENTRY
_mesa_DisableClientState( GLenum cap );


#endif

==> MesaLib-7.10.tar.bz2: Mesa-7.10/src/mesa/main/enable.h <==
/**
 * \file enable.h
 * Enable/disable/query GL capabilities.
 */

/*
 * Mesa 3-D graphics library
 * Version:  3.5
 *
 * Copyright (C) 1999-2001  Brian Paul   All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * BRIAN PAUL BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */


#ifndef ENABLE_H
#define ENABLE_H


#include "glheader.h"

struct gl_context;


extern void
_mesa_set_enable( struct gl_context* ctx, GLenum cap, GLboolean state );

extern void GLAPIENTRY
_mesa_Disable( GLenum cap );

extern void GLAPIENTRY
_mesa_Enable( GLenum cap );

extern GLboolean GLAPIENTRY
_mesa_IsEnabled( GLenum cap );

extern void
_mesa_set_enablei(struct gl_context *ctx, GLenum cap, GLuint index, GLboolean state);

extern void GLAPIENTRY
_mesa_DisableIndexed( GLenum cap, GLuint index );

extern void GLAPIENTRY
_mesa_EnableIndexed( GLenum cap, GLuint index );

extern GLboolean GLAPIENTRY
_mesa_IsEnabledIndexed( GLenum cap, GLuint index );

extern void GLAPIENTRY
_mesa_EnableClientState( GLenum cap );

extern void GLAPIENTRY
_mesa_DisableClientState( GLenum cap );


#endif
